var x = "$";

export var result = `64 = ${x}`;
